local C = Winning_Constants

local M = {}


M.test_Winning_Chat_Icon = function()
    assert(Winning_Chat_Icon('foo'), "Adding chat icon failed.")
end


M.test_Winning_Chat = function()
    local result = Winning_Chat("Foo Message")
    assert(string.match(result, 'Winning:'))
end


M.test_Winning_Log = function()
    local d = C.ADDON_DEBUG

    C.ADDON_DEBUG = false
    local result = Winning_Log("Foo Message")
    assert(result == nil, "Message should not be logged with DEBUG off.")

    C.ADDON_DEBUG = true
    local result = Winning_Log("Foo Message")
    assert(result, "Message should be logged with DEBUG on.")

    C.ADDON_DEBUG = d
end


M.test_Winning_Duration = function()
    -- zero minutes
    result = Winning_Duration(15)
    assert(result == "0:15")

    -- 99% case of minutes and seconds
    result = Winning_Duration(123)
    assert(result == "2:03")

    -- more than 2 digits of minutes
    result = Winning_Duration(6666)
    assert(result == "111:06", string.format("Expected '111:06', got: %s", result))
end


M.test_Winning_Parse_Name = function()
    local tests = {}

    -- Server here comes from GetRealmName mock.
    local_server = GetRealmName()
    tests["Localchar"] = {"Localchar", local_server}
    tests["Char-Server"] = {"Char", "Server"}
    tests["ç˙å®-ß´®√´®"] = {"ç˙å®", "ß´®√´®"}

    --assert(#tests == 3, string.format("Expected table length of 3, got %s", #tests))
    for k, v in pairs(tests) do
        local char, server = Winning_Parse_Name(k)
        assert(char)
        assert(server)
        assert(char == v[1], string.format("Char names mismatched: %s, %s", char, v[1]))
        assert(server == v[2], string.format("Server names mismatched: %s, %s", server, v[2]))
    end
end

M.test_Winning_UUID = function()
    -- TODO: Implement
    assert(true)
end

M.test_Winning_Humanify = function()
    -- TODO: Implement
    assert(true)
end

return M
